@@ -1,7 +1,7 @@
 package Complete::Module;
 
-our $DATE = '2015-01-13'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2015-03-03'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -59,6 +59,19 @@ _
             summary => 'Whether to do case-insensitive search',
             schema  => 'bool*',
         },
+        path_sep => {
+            summary => 'Path separator',
+            schema  => 'str*',
+            description => <<'_',
+
+For convenience in shell (bash) completion, instead of defaulting to `::` all
+the time, will look at `word`. If word does not contain any `::` then will
+default to `/`. This is because `::` (contains colon) is rather problematic as
+it is by default a word-break character in bash and the word needs to be quoted
+to avoid word-breaking by bash.
+
+_
+        },
         map_case => {
             schema => 'bool',
         },
@@ -128,8 +141,11 @@ sub complete_module {
     # use '.' if user uses that.) Using "::" in bash means user needs to use
     # quote (' or ") to make completion behave as expected since : is by default
     # a word break character in bash/readline.
-    my $sep = $word =~ /::/ ? '::' :
-        $word =~ /\./ ? '.' : '/';
+    my $sep = $args{path_sep};
+    unless (defined $sep) {
+        $sep = $word =~ /::/ ? '::' :
+            $word =~ /\./ ? '.' : '/';
+    }
 
     # find shortcut prefixes
     {
@@ -207,7 +223,7 @@ Complete::Module - Complete with installed Perl module names
 
 =head1 VERSION
 
-This document describes version 0.15 of Complete::Module (from Perl distribution Complete-Module), released on 2015-01-13.
+This document describes version 0.16 of Complete::Module (from Perl distribution Complete-Module), released on 2015-03-03.
 
 =head1 SYNOPSIS
 
@@ -277,6 +293,16 @@ C<Dist::Zilla::Plugin> (or C<Dist::Zilla::Plugin::>) and word is C<F>, you can g
 C<['FakeRelease', 'FileFinder::', 'FinderCode']> (those are modules under the
 C<Dist::Zilla::Plugin::> namespace).
 
+=item * B<path_sep> => I<str>
+
+Path separator.
+
+For convenience in shell (bash) completion, instead of defaulting to C<::> all
+the time, will look at C<word>. If word does not contain any C<::> then will
+default to C</>. This is because C<::> (contains colon) is rather problematic as
+it is by default a word-break character in bash and the word needs to be quoted
+to avoid word-breaking by bash.
+
 =item * B<word>* => I<str>
 
 =back
@@ -319,7 +345,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-M
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Complete-Module>.
+Source repository is at L<https://github.com/perlancar/perl-Complete-Module>.
 
 =head1 BUGS
 
